@@ -1,4 +1,4 @@
-#ident "$Id: wrmsr.c,v 1.2 2003/01/07 03:07:23 hpa Exp $"
+#ident "$Id: wrmsr.c,v 1.3 2004/07/20 15:54:59 hpa Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *   Copyright 2000 Transmeta Corporation - All Rights Reserved
@@ -105,15 +105,10 @@ int main(int argc, char *argv[])
     }
   }
   
-  if ( lseek(fd, reg, SEEK_SET) != reg ) {
-    perror("wrmsr:seek");
-    exit(127);
-  }
-
   while ( optind < argc ) {
-    data = strtouq(argv[optind++], NULL, 0);
-    if ( write(fd, &data, sizeof data) != sizeof data ) {
-      perror("wrmsr:write");
+    data = strtoull(argv[optind++], NULL, 0);
+    if ( pwrite(fd, &data, sizeof data, reg) != sizeof data ) {
+      perror("wrmsr:pwrite");
       exit(127);
     }
   }
@@ -122,4 +117,3 @@ int main(int argc, char *argv[])
 
   exit(0);
 }
-
